import pandas as pd
import matplotlib.pyplot as plt

# Step 1: Create a sample dataset
data = {
    "Region": ["North", "South", "East", "West"],
    "Category": ["Technology", "Furniture", "Office Supplies", "Technology"],
    "Sales": [5000, 3000, 4000, 7000],
    "Profit": [1200, 800, 1000, 1500],
}

# Convert the data into a DataFrame
df = pd.DataFrame(data)

# Save the dataset to a CSV file for Tableau
csv_file_path = "sales_data.csv"
df.to_csv(csv_file_path, index=False)
print(f"Sample dataset saved to {csv_file_path}")

# Step 2: Visualize data in Python
# Create a bar chart for Sales by Region
plt.figure(figsize=(8, 6))
plt.bar(df["Region"], df["Sales"], color="skyblue")
plt.title("Sales by Region", fontsize=16)
plt.xlabel("Region", fontsize=12)
plt.ylabel("Sales", fontsize=12)
plt.show()

# Create a scatter plot for Sales vs Profit
plt.figure(figsize=(8, 6))
plt.scatter(df["Sales"], df["Profit"], color="green")
for i, category in enumerate(df["Category"]):
    plt.text(df["Sales"][i], df["Profit"][i], category, fontsize=10)
plt.title("Sales vs Profit by Category", fontsize=16)
plt.xlabel("Sales", fontsize=12)
plt.ylabel("Profit", fontsize=12)
plt.grid(True)
plt.show()

# Instructions for Tableau:
# 1. Open Tableau and load the generated 'sales_data.csv' file.
# 2. Use 'Region' for rows and 'Sales' for columns to create a bar chart.
# 3. Use 'Sales' and 'Profit' to create a scatter plot, adding 'Category' as a label.
# 4. Explore additional features such as filters, colors, and tooltips to enhance interactivity.

print("Visualization script executed. Use 'sales_data.csv' in Tableau for advanced visualizations.")
