import pandas as pd
import matplotlib.pyplot as plt

# Step 1: Create a sample dataset
data = {
    "Region": ["North", "South", "East", "West"],
    "Category": ["Technology", "Furniture", "Office Supplies", "Technology"],
    "Sales": [5000, 3000, 4000, 7000],
    "Profit": [1200, 800, 1000, 1500],
}

# Convert the data into a DataFrame
df = pd.DataFrame(data)

# Save the dataset to a CSV file for Power BI
csv_file_path = "powerbi_sales_data.csv"
df.to_csv(csv_file_path, index=False)
print(f"Sample dataset saved to {csv_file_path}")

# Step 2: Visualize data in Python
# Create a bar chart for Sales by Region
plt.figure(figsize=(8, 6))
plt.bar(df["Region"], df["Sales"], color="skyblue")
plt.title("Sales by Region", fontsize=16)
plt.xlabel("Region", fontsize=12)
plt.ylabel("Sales", fontsize=12)
plt.show()

# Create a scatter plot for Sales vs Profit
plt.figure(figsize=(8, 6))
plt.scatter(df["Sales"], df["Profit"], color="green")
for i, category in enumerate(df["Category"]):
    plt.text(df["Sales"][i], df["Profit"][i], category, fontsize=10)
plt.title("Sales vs Profit by Category", fontsize=16)
plt.xlabel("Sales", fontsize=12)
plt.ylabel("Profit", fontsize=12)
plt.grid(True)
plt.show()

# Instructions for Power BI:
# 1. Open Power BI Desktop and load the generated 'powerbi_sales_data.csv' file.
# 2. Use 'Region' for rows and 'Sales' for values to create a bar chart.
# 3. Use 'Sales' and 'Profit' to create a scatter plot, adding 'Category' as a legend.
# 4. Customize visualizations using Power BI's rich formatting options.

print("Visualization script executed. Use 'powerbi_sales_data.csv' in Power BI for advanced visualizations.")
